import pytest
from csirtg_network.interfaces import *


def test_default_address():
    i = default_address()
    print(i)

    assert i

    assert address_to_interface(i)


def test_default_interface():
    i = default_interface()
    assert i

    print(i)
    assert interface_to_address(i)


def test_resolve_endpoint():
    i = default_address()

    endpoint = resolve_endpoint(i, 5590)

    print(endpoint)

    assert endpoint == 'tcp://%s:%d' % (i, 5590)


from csirtg_network.fqdn import *


def test_url_fqdn():
    assert url_resolve('https://example.com') == 'example.com'


def test_fqdn_resolve():
    assert fqdn_resolve('csirtgadgets.com')


def test_ns_resolve():
    assert ns_resolve('csirtgadgets.com')


def test_peers_resolve():
    i = fqdn_resolve('csirtgadgets.com')
    assert peers_resolve(i)
